@@ -34,7 +34,7 @@ pub struct UpsPatch {
 }
 
 impl UpsPatch {
-    const CANON_HEADER: [u8; 4] = [0x55, 0x50, 0x53, 0x31];
+    pub const CANON_HEADER: [u8; 4] = [0x55, 0x50, 0x53, 0x31];
 
     /// Creates a Patch from the given source and target files
     /// # Arguments
@@ -213,7 +213,16 @@ impl UpsPatch {
         return output;
     }
     /// Returns a vector with the contents of the patch.ups file
-    pub fn get_patch_file_contents(&self) -> Vec<u8> {
+    pub fn get_patch_file_contents(&self) -> Vec<u8>{
+        let mut output = UpsPatch::tailless_bytearray(self.source_file_size,
+                                                      self.target_file_size,
+                                                      &self.changes,
+                                                      self.source_crc32,
+                                                      self.target_crc32);
+        output.extend(self.patch_crc32.to_le_bytes());
+        return output
+    }
+/*    pub fn get_patch_file_contents(&self) -> Vec<u8> {
         let mut output: Vec<u8> = vec![];
         output.extend(UpsPatch::CANON_HEADER);
         output.extend(UpsPatch::encode(self.source_file_size));
@@ -229,7 +238,7 @@ impl UpsPatch {
         output.extend(self.target_crc32.to_le_bytes());
         output.extend(self.patch_crc32.to_le_bytes());
         return output;
-    }
+    }*/
 
     /// Checks if the given file contents matches the source file for the UPS patch
     pub fn file_is_source(&self, content: &Vec<u8>) -> bool {
